pub enum StructuralTofProjectError {
Domain(DomainError),
Workflow(StructuralTofMultiBankError),
Refinement(StructuralTofMultiBankRefinementError),
DuplicateAnalysis {
analysis_id: RecordId,
},
DuplicateHistogramOwnership {
histogram_id: RecordId,
},
UnknownHistogram {
histogram_id: RecordId,
},
HistogramStateMismatch {
histogram_id: RecordId,
},
PhaseOrderMismatch {
histogram_id: RecordId,
},
PhaseStateMismatch {
phase_id: RecordId,
},
}Expand description
Invalid project-level structural TOF state.
Variants
Domain(DomainError)
Application-neutral project validation failed.
Workflow(StructuralTofMultiBankError)
Structural TOF input failed validation.
Refinement(StructuralTofMultiBankRefinementError)
Structural TOF solver/checkpoint state failed validation.
DuplicateAnalysis
More than one analysis has the same stable identity.
DuplicateHistogramOwnership
A TOF histogram is assigned to multiple structural analyses.
UnknownHistogram
Analysis references a missing TOF histogram.
HistogramStateMismatch
Bank pattern or initial instrument differs from its histogram record.
PhaseOrderMismatch
Histogram phase references are not exactly the shared analysis phase.
PhaseStateMismatch
Analysis phase identity, label, definition, or provider contract differs.