pub enum TofMultiBankProjectError {
Domain(DomainError),
Workflow(TofMultiBankGeometryError),
DuplicateAnalysis {
analysis_id: RecordId,
},
DuplicateHistogramOwnership {
histogram_id: RecordId,
},
UnknownHistogram {
histogram_id: RecordId,
},
HistogramStateMismatch {
histogram_id: RecordId,
},
PhaseOrderMismatch {
histogram_id: RecordId,
},
PhaseStateMismatch {
phase_id: RecordId,
},
LatticeStateMismatch {
phase_id: RecordId,
},
}Expand description
Invalid project-level joint multi-bank TOF state.
Variants
Domain(DomainError)
Application-neutral project validation failed.
Workflow(TofMultiBankGeometryError)
Joint geometry input, options, or checkpoint validation failed.
DuplicateAnalysis
More than one analysis has the same stable identity.
DuplicateHistogramOwnership
A TOF histogram is assigned to multiple joint analyses.
UnknownHistogram
Analysis references a missing TOF histogram.
HistogramStateMismatch
Bank pattern or initial instrument differs from its histogram record.
PhaseOrderMismatch
Active phase order differs from the histogram references.
PhaseStateMismatch
Analysis phase label or identity differs from project state.
LatticeStateMismatch
Shared initial cell or exact symmetry setting differs from project state.