pub struct RietveldIterationRecord {Show 13 fields
pub iteration: usize,
pub objective: f64,
pub objective_change: f64,
pub scaled_step_norm: f64,
pub damping: f64,
pub cg_iterations: usize,
pub backtracks: usize,
pub parameter_changes: Vec<ParameterChange>,
pub topology_changes: Vec<RietveldTopologyChange>,
pub rwp: f64,
pub rp: f64,
pub chi_square: f64,
pub reduced_chi_square: f64,
}Expand description
One accepted native Rietveld Gauss–Newton iteration.
Fields
iteration: usizeOne-based attempted iteration.
objective: f64Accepted weighted residual sum of squares divided by two.
objective_change: f64Previous objective minus accepted objective.
scaled_step_norm: f64Accepted scaled Euclidean step norm.
damping: f64Damping used to construct the accepted step.
cg_iterations: usizeConjugate-gradient iterations used.
backtracks: usizeHalf-step backtracks used.
parameter_changes: Vec<ParameterChange>Accepted physical parameter changes.
topology_changes: Vec<RietveldTopologyChange>Reflection families added or removed by accepted lattice motion.
rwp: f64Accepted Rwp.
rp: f64Accepted unweighted profile residual.
chi_square: f64Accepted weighted residual sum of squares.
reduced_chi_square: f64Accepted chi-square divided by residual degrees of freedom.