pub struct TofMultiBankLatticeIterationRecord {
pub iteration: usize,
pub bank_metrics: Vec<ResidualEvaluation>,
pub metrics: TofMultiBankMetrics,
pub maximum_relative_intensity_change: f64,
pub maximum_absolute_background_change: f64,
pub scaled_lattice_step_norm: f64,
pub lattice_parameter_changes: Vec<TofLatticeParameterChange>,
}Expand description
One atomically accepted local-extraction plus shared-lattice cycle.
Fields
iteration: usizeOne-based accepted cycle index.
bank_metrics: Vec<ResidualEvaluation>Bank-local residual records in input order.
metrics: TofMultiBankMetricsAggregate residual metrics with shared lattice parameters counted once.
maximum_relative_intensity_change: f64Largest relative bank-local intensity change.
maximum_absolute_background_change: f64Largest absolute bank-local background-coefficient change.
scaled_lattice_step_norm: f64Norm of the accepted shared lattice step in scaled coordinates.
lattice_parameter_changes: Vec<TofLatticeParameterChange>Physical shared-cell changes in deterministic phase/parameter order.