RefinementEventSink

Trait RefinementEventSink 

pub trait RefinementEventSink: Send {
    // Required method
    fn emit(&mut self, event: &RefinementEvent) -> Result<(), String>;
}
Synchronous event consumer called only at orchestration boundaries.

Required Methods

fn emit(&mut self, event: &RefinementEvent) -> Result<(), String>

Consume one immutable event or return a host-facing failure message.

Errors

Returns a message when the host cannot consume the event. The runtime isolates the failure and detaches this sink.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors